@@ -37,7 +37,7 @@ else:
         soname = "libxcb.so"
 lib = ffi.dlopen(soname)
 
-__xcb_proto_version__ = "1.14.1"
+__xcb_proto_version__ = "1.15.2"
 __version__ = 'placeholder'
 
 X_PROTOCOL = lib.X_PROTOCOL
@@ -126,10 +126,11 @@ class Unpacker(object):
     @classmethod
     def synthetic(cls, data, format):
         self = cls.__new__(cls)
+        self.__init__(len(data))
         self.buf = data
         self.offset = 0
         self.size = len(data)
-        self.size
+        return self
 
 
 class CffiUnpacker(Unpacker):
